function [sys,x0,str,ts] = sfuntmpl(t, x, u, flag, Da, phi, beta, B)
%
%   Copyright 1990-2002 The MathWorks, Inc.
%   $Revision: 1.18 $
%
% The following outlines the general structure of an S-function.
%
switch flag,
 
  %%%%%%%%%%%%%%%%%%
  % Initialization %
  %%%%%%%%%%%%%%%%%%
  case 0,
    [sys,x0,str,ts]=mdlInitializeSizes;
 
  %%%%%%%%%%%%%%%
  % Derivatives %
  %%%%%%%%%%%%%%%
  case 1,
    sys=mdlDerivatives(t,x,u,Da,phi,beta,B);
 
  %%%%%%%%%%
  % Update %
  %%%%%%%%%%
  case 2,
    sys=mdlUpdate(t,x,u);
 
  %%%%%%%%%%%
  % Outputs %
  %%%%%%%%%%%
  case 3,
    sys=mdlOutputs(t,x,u);
 
  %%%%%%%%%%%%%%%%%%%%%%%
  % GetTimeOfNextVarHit %
  %%%%%%%%%%%%%%%%%%%%%%%
  case 4,
    sys=mdlGetTimeOfNextVarHit(t,x,u);
 
  %%%%%%%%%%%%%
  % Terminate %
  %%%%%%%%%%%%%
  case 9,
    sys=mdlTerminate(t,x,u);
 
  %%%%%%%%%%%%%%%%%%%%
  % Unexpected flags %
  %%%%%%%%%%%%%%%%%%%%
  otherwise
    error(['Unhandled flag = ',num2str(flag)]);
 
end
 
% end sfuntmpl
 
%
%====================================================================
% mdlInitializeSizes
% Return the sizes, initial conditions, and sample times for the S-function.
%====================================================================
%
function [sys,x0,str,ts]=mdlInitializeSizes
 
%
% call simsizes for a sizes structure, fill it in and convert it to a
% sizes array.
%
% Note that in this example, the values are hard coded.  This is not a
% recommended practice as the characteristics of the block are typically
% defined by the S-function parameters.
%
sizes = simsizes;
 
sizes.NumContStates  = 2;  % ӪA(states)
sizes.NumDiscStates  = 0;
sizes.NumOutputs     = 2;  % ӿX(outputs)
sizes.NumInputs      = 1;  % @ӿJ (input)
sizes.DirFeedthrough = 1;
sizes.NumSampleTimes = 1;   % at least one sample time is needed
 
sys = simsizes(sizes);
 
%
% initialize the initial conditions
%
x0  = [0; 0];  % A_l
 
%
% str is always an empty matrix
%
str = [ ];
 
%
% initialize the array of sample times
%
ts  = [0 0];
 
% end mdlInitializeSizes
 
%
%====================================================================
% mdlDerivatives
% Return the derivatives for the continuous states.
%====================================================================
%
function sys=mdlDerivatives(t,x,u,Da,phi,beta,B)
 
sys = [-x(1)+Da*(1-x(1))*exp(x(2)/(1+x(2)/phi));
      -(1+beta)*x(2)+B*Da*(1-x(1))*exp(x(2)/(1+x(2)/phi))+u(1)];  % tμҦ
 
% end mdlDerivatives
 
%
%====================================================================
% mdlUpdate
% Handle discrete state updates, sample time hits, and major time step
% requirements.
%====================================================================
%
function sys=mdlUpdate(t,x,u)
 
sys = [ ];
 
% end mdlUpdate
 
%
%====================================================================
% mdlOutputs
% Return the block outputs.
%====================================================================
%
function sys=mdlOutputs(t,x,u)
 
sys = [x(1); x(2)];  % tοX
 
% end mdlOutputs
 
%
%====================================================================
% mdlGetTimeOfNextVarHit
% Return the time of the next hit for this block.  Note that the result is
% absolute time.  Note that this function is only used when you specify a
% variable discrete-time sample time [-2 0] in the sample time array in
% mdlInitializeSizes.
%====================================================================
%
function sys=mdlGetTimeOfNextVarHit(t,x,u)
 
sampleTime = 1;    %  Example, set the next hit to be one second later.
sys = t + sampleTime;
 
% end mdlGetTimeOfNextVarHit
 
%
%====================================================================
% mdlTerminate
% Perform any end of simulation tasks.
%====================================================================
%
function sys=mdlTerminate(t,x,u)
 
sys = [ ];
 
% end mdlTerminate
